@@ -454,6 +454,10 @@ class CaseHandler(object):
                 {"gene_fusion_report_research": EXISTS_NOT_NULL},
                 {"individuals.splice_junctions_bed": EXISTS_NOT_NULL},
                 {"individuals.rna_coverage_bigwig": EXISTS_NOT_NULL},
+                {"RNAfusion_report": EXISTS_NOT_NULL},
+                {"RNAfusion_report_research": EXISTS_NOT_NULL},
+                {"RNAfusion_inspector": EXISTS_NOT_NULL},
+                {"RNAfusion_inspector_research": EXISTS_NOT_NULL},
             ],
         }
         return [case["_id"] for case in self.case_collection.find(query)]
@@ -851,7 +855,6 @@ class CaseHandler(object):
         ]
 
         try:
-
             for vcf_file in files:
                 # Check if file exists
                 if not case_obj["vcf_files"].get(vcf_file["file_name"]):
@@ -945,6 +948,10 @@ class CaseHandler(object):
             - reference_info: path to the pipeline reference version report file
             - rerun_requested: Is set to False since that is probably what happened
             - research_requested: Boolean, if research variants where requested for this case
+            - RNAfusion_inspector: path to the RNA fusion inspector report
+            - RNAfusion_inspector_research: path to the research RNA fusion inspector report
+            - RNAfusion_report: path to the RNA fusion report
+            - RNAfusion_report_research: path to the research RNA fusion report
             - smn_tsv: path to static SMN TSV file
             - status: case status
             - sv_rank_model_version: If there is a new sv rank model
@@ -1007,6 +1014,10 @@ class CaseHandler(object):
                 "rerun_requested": case_obj.get("rerun_requested", False),
                 "research_requested": case_obj.get("research_requested", False),
                 "reference_info": case_obj.get("reference_info"),
+                "RNAfusion_inspector": case_obj.get("RNAfusion_inspector"),
+                "RNAfusion_inspector_research": case_obj.get("RNAfusion_inspector_research"),
+                "RNAfusion_report": case_obj.get("RNAfusion_report"),
+                "RNAfusion_report_research": case_obj.get("RNAfusion_report_research"),
                 "smn_tsv": case_obj.get("smn_tsv"),
                 "status": case_obj.get("status"),
                 "sv_rank_model_version": case_obj.get("sv_rank_model_version"),
@@ -1042,6 +1053,10 @@ class CaseHandler(object):
             "multiqc_rna",
             "rank_model_version",
             "reference_info",
+            "RNAfusion_inspector",
+            "RNAfusion_inspector_research",
+            "RNAfusion_report",
+            "RNAfusion_report_research",
             "smn_tsv",
             "sv_rank_model_version",
         ]:
@@ -1212,7 +1227,6 @@ class CaseHandler(object):
 
         n_status_updated = 0
         for old_var in old_eval_variants:
-
             # search for the same variant in newly uploaded vars for this case
             display_name = old_var["display_name"]
 
