@@ -84,7 +84,7 @@ variant = dict(
     gene_lists=list,
     manual_rank=int,  # choices=[0, 1, 2, 3, 4, 5]
     dismiss_variant=list,
-    acmg_evaluation=str,  # choices=ACMG_TERMS
+    acmg_classification=str,  # choices=ACMG_TERMS
 )
 
 compound = dict(
