@@ -1,7 +1,8 @@
-from flask import Blueprint
+from flask import Blueprint, jsonify
 
 from scout.server.extensions import store
-from scout.server.utils import templated, public_endpoint
+from scout.server.utils import public_endpoint, templated
+
 from . import controllers
 
 omim_bp = Blueprint("diagnoses", __name__, template_folder="templates")
@@ -21,5 +22,14 @@ def omim_diagnosis(omim_nr):
 def omim_diagnoses():
     """Display all OMIM diagnoses available in database"""
 
-    data = {"terms": store.disease_terms()}
+    data = controllers.disease_terms(store)
     return data
+
+
+@omim_bp.route("/api/v1/diagnoses")
+@public_endpoint
+def api_diagnoses():
+    """Return JSON data about OMIM diseases in the database."""
+
+    data = controllers.disease_terms(store)
+    return jsonify(data)
