@@ -1,13 +1,15 @@
 import copy
+import datetime
 import logging
 
 import responses
-from flask import current_app, url_for
+from flask import url_for
 from flask_login import current_user
 
 from scout.constants import IGV_TRACKS
 from scout.server.app import create_app
 from scout.server.blueprints.variant.controllers import (
+    check_reset_variant_classification,
     get_igv_tracks,
     has_rna_tracks,
     observations,
@@ -15,11 +17,59 @@ from scout.server.blueprints.variant.controllers import (
     variant,
     variant_rank_scores,
 )
+from scout.server.blueprints.variant.utils import evaluation
 from scout.server.extensions import cloud_tracks, loqusdb, store
 
 LOG = logging.getLogger(__name__)
 
 
+def test_check_reset_variant_classification(app, case_obj, variant_obj):
+    """Test the check_reset_variant_classification controller
+    Assume we are in the situation when it will trigger to clear classifications,
+    and make sure it does clear the classification."""
+
+    # GIVEN an app with a current user
+    with app.test_client() as client:
+        client.get(url_for("auto_login"))
+
+        # GIVEN a variant classified according to ACMG
+        assert store.variant_collection.find_one_and_update(
+            {"_id": variant_obj["_id"]},
+            {"$set": {"acmg_classification": 1}},
+        )
+
+        # WHEN retrieving the variant again,
+        current_variant = store.variant(variant_obj["_id"])
+        # THEN the classification was acutally set
+        assert current_variant.get("acmg_classification") is not None
+
+        # GIVEN that there are no separate evaluations stored for the variant
+        assert len(list(store.get_evaluations_case_specific(variant_obj["document_id"]))) == 0
+
+        # GIVEN an evaluation object for this classification that is not stored
+        deleted_evaluation = dict(
+            variant_specific=variant_obj["document_id"],
+            variant_id=variant_obj["variant_id"],
+            institute_id=case_obj["owner"],
+            case_id=case_obj["case_id"],
+            classification="LP",
+            criteria=[],
+            user_id=current_user.email,
+            user_name=current_user.name,
+            created_at=datetime.datetime.now(),
+        )
+        deleted_evaluation_obj = evaluation(store, deleted_evaluation)
+
+        # WHEN checking if variant evaluations have been removed,
+        # THEN it returns true
+        assert check_reset_variant_classification(store, deleted_evaluation_obj, "link")
+
+        # WHEN retrieving the variant again,
+        current_variant = store.variant(variant_obj["_id"])
+        # THEN the classification has now been cleared
+        assert current_variant.get("acmg_classification") is None
+
+
 def test_variant_rank_scores(case_obj, variant_obj):
     """Test the function that retrieves variant rank scores and info regrding the rank score model applied"""
 
@@ -123,7 +173,6 @@ def test_get_igv_tracks():
 
 @responses.activate
 def test_observations_controller_non_existing(app, institute_obj, case_obj, loqusdburl):
-
     # GIVEN an app with a connected loqusdb instance
     loqus_id = "test"
     assert app.config["LOQUSDB_SETTINGS"][loqus_id]
@@ -247,10 +296,13 @@ def test_observations_controller_sv(app, sv_variant_obj, institute_obj, loqusdbu
     assert data[loqus_id]["cases"][0]["variant"]["_id"] == sv_variant_obj["_id"]
 
 
-def test_case_variant_check_causatives(app, real_variant_database):
+def test_case_matching_causatives(app, real_variant_database):
+    """Testing the case_matching_causatives function, that returns variants for a case that
+    were found causatives in other cases from the same institutet.
+    - given that the variant is found in an affected individual of the case
+    """
+    # GIVEN a populated database
     adapter = real_variant_database
-
-    # GIVEN a populated database with variants
     case_obj = adapter.case_collection.find_one()
     assert case_obj
     institute_obj = adapter.institute_collection.find_one()
@@ -265,7 +317,10 @@ def test_case_variant_check_causatives(app, real_variant_database):
     other_case["_id"] = "other_case"
     other_case["internal_id"] = "other_case"
     other_case["display_name"] = "other_case"
-    # insert this case into database
+    # GIVEN that the other case contains the variant in one affected individual
+    for ind in other_case["individuals"]:
+        ind["phenotype"] = 2  # affected
+
     adapter.case_collection.insert_one(other_case)
 
     # GIVEN that the other case shares a variant with the original case,
@@ -274,8 +329,7 @@ def test_case_variant_check_causatives(app, real_variant_database):
     other_variant["_id"] = "other_variant"
     adapter.variant_collection.insert_one(other_variant)
 
-    LOG.debug("other variant: {}".format(other_variant))
-    assert sum(1 for i in adapter.event_collection.find()) == 0
+    assert sum(1 for _ in adapter.event_collection.find()) == 0
 
     # WHEN the original case has a causative variant flagged,
     link = "junk/{}".format(variant_obj["_id"])
@@ -291,22 +345,21 @@ def test_case_variant_check_causatives(app, real_variant_database):
     event_obj = adapter.event_collection.find_one()
     assert event_obj["link"] == link
 
-    # THEN an app will find the matching causative
+    # THEN an function will find the matching causative
     with app.test_client() as client:
         resp = client.get(url_for("auto_login"))
-        other_causatives = adapter.check_causatives(
-            case_obj=other_case, institute_obj=institute_obj
+        other_causatives = adapter.case_matching_causatives(
+            case_obj=other_case,
         )
-        LOG.debug("other causatives: {}".format(other_causatives))
-        assert sum(1 for i in other_causatives) > 0
+        assert sum(1 for _ in other_causatives) == 1
 
 
-def test_case_variant_check_causatives_carrier(app, real_variant_database):
-    # GIVEN a case with a causative variant flagged,
+def test_case_matching_causatives_carrier(app, real_variant_database):
+    """Testing the case_matching_causatives function, which should NOT return matching causatives
+    when the the case has not affected individuals with the variant"""
 
+    # GIVEN a populated database
     adapter = real_variant_database
-
-    # GIVEN a populated database with variants
     case_obj = adapter.case_collection.find_one()
     assert case_obj
     institute_obj = adapter.institute_collection.find_one()
@@ -321,10 +374,11 @@ def test_case_variant_check_causatives_carrier(app, real_variant_database):
     other_case["_id"] = "other_case"
     other_case["internal_id"] = "other_case"
     other_case["display_name"] = "other_case"
-    # GIVEN another case with the same variant for an unaffected individual,
-    other_case["individuals"][0]["phenotype"] = 1
-    other_case["individuals"][1]["phenotype"] = 1
-    other_case["individuals"][2]["phenotype"] = 1
+
+    # GIVEN that the another case has the variant in an unaffected individual
+    for ind in other_case["individuals"]:
+        ind["phenotype"] = 1  # unaffected
+
     # insert this case into database
     adapter.case_collection.insert_one(other_case)
 
@@ -334,9 +388,6 @@ def test_case_variant_check_causatives_carrier(app, real_variant_database):
     other_variant["_id"] = "other_variant"
     adapter.variant_collection.insert_one(other_variant)
 
-    LOG.debug("other variant: {}".format(other_variant))
-    assert sum(1 for i in adapter.event_collection.find()) == 0
-
     # WHEN the original case has a causative variant flagged,
     link = "junk/{}".format(variant_obj["_id"])
     updated_case = adapter.mark_causative(
@@ -347,18 +398,13 @@ def test_case_variant_check_causatives_carrier(app, real_variant_database):
         variant=variant_obj,
     )
 
-    # THEN an event object should have been created linking the variant
-    event_obj = adapter.event_collection.find_one()
-    assert event_obj["link"] == link
-
-    # THEN an app will find the matching causative
+    # THEN the function will NOT return the matching causative from the first case
     with app.test_client() as client:
         resp = client.get(url_for("auto_login"))
-        other_causatives = adapter.check_causatives(
-            case_obj=other_case, institute_obj=institute_obj
+        other_causatives = adapter.case_matching_causatives(
+            case_obj=other_case,
         )
-        LOG.debug("other causatives: {}".format(other_causatives))
-        assert sum(1 for i in other_causatives) == 0
+        assert sum(1 for _ in other_causatives) == 0
 
 
 def test_variant_controller_with_compounds(app, institute_obj, case_obj):
@@ -402,7 +448,6 @@ def test_variant_controller_with_compounds(app, institute_obj, case_obj):
 
 
 def test_variant_controller_with_clnsig(app, institute_obj, case_obj):
-
     ## GIVEN a populated database with a variant
     variant_obj = store.variant_collection.find_one({"clnsig": {"$exists": True}})
     assert variant_obj
@@ -435,7 +480,6 @@ def test_variant_controller_with_clnsig(app, institute_obj, case_obj):
 
 
 def test_variant_controller(app, institute_obj, case_obj, variant_obj):
-
     ## GIVEN a populated database with a variant
     category = "snv"
     with app.test_client() as client:
