@@ -3,8 +3,10 @@
 from flask import url_for
 
 from scout.server.links import (
+    BEACON_LINK_TEMPLATE,
     add_gene_links,
     alamut_link,
+    beacon_link,
     cbioportal,
     ckb_gene,
     mutalyzer,
@@ -12,8 +14,37 @@ from scout.server.links import (
     snp_links,
 )
 
+BUILD_37 = 37
+BUILD_38 = 38
 
-def test_alamut_link(app, institute_obj, variant_obj):
+BEACON_BUILD_37 = "GRCh37"
+BEACON_BUILD_38 = "GRCh38"
+
+
+def test_beacon_link_37(variant_obj):
+    """Test building a beacon link for a variant in build 37"""
+    # GIVEN a variant in genome build 37
+    build = BUILD_37
+
+    # THEN the Beacon link should reflect the variant build
+    expected_link = BEACON_LINK_TEMPLATE.format(this=variant_obj, build=BEACON_BUILD_37)
+    link = beacon_link(variant_obj, build)
+    assert expected_link == link
+
+
+def test_beacon_link_38(variant_obj):
+    """Test building a beacon link for a variant in build 38"""
+
+    # GIVEN a variant in genome build 38
+    build = BUILD_38
+
+    # THEN the Beacon link should reflect the variant build
+    expected_link = BEACON_LINK_TEMPLATE.format(this=variant_obj, build=BEACON_BUILD_38)
+    link = beacon_link(variant_obj, build)
+    assert expected_link == link
+
+
+def test_alamut_link_build38(app, institute_obj, variant_obj):
     """Test to add a link to alamut browser"""
 
     # GIVEN an institute with settings for Alamut Visual Plus
@@ -22,9 +53,6 @@ def test_alamut_link(app, institute_obj, variant_obj):
     institute_obj["alamut_key"] = alamut_api_key
     institute_obj["alamut_institution"] = alamut_api_institute
 
-    # GIVEN that genome build 38 is provided
-    build = 38
-
     # GIVEN that the app settings contain parameter HIDE_ALAMUT_LINK = False
     app.config["HIDE_ALAMUT_LINK"] = False
 
@@ -34,7 +62,7 @@ def test_alamut_link(app, institute_obj, variant_obj):
         assert resp.status_code == 200
 
         # WHEN the alamut link is created
-        link_to_alamut = alamut_link(institute_obj, variant_obj, 38)
+        link_to_alamut = alamut_link(institute_obj, variant_obj, BUILD_38)
         # THEN the link should contain genome build info
         assert "GRCh38" in link_to_alamut
         # As well as Alamut Visual Plus API key and institution
@@ -42,35 +70,35 @@ def test_alamut_link(app, institute_obj, variant_obj):
         assert alamut_api_institute in link_to_alamut
 
 
-def test_add_gene_links():
+def test_add_gene_links_build37():
     """Test to add gene links to a gene object"""
     # GIVEN a minimal gene and a genome build
     gene_obj = {"hgnc_id": 257}
-    build = 37
+
     # WHEN adding the gene links
-    add_gene_links(gene_obj, build)
+    add_gene_links(gene_obj, BUILD_37)
     # THEN assert some links are added
     assert "hgnc_link" in gene_obj
 
 
-def test_add_hg38_gene_links():
+def test_add_gene_links_build38():
     """Test to add hg38 gene links to a gene object"""
     # GIVEN a minimal gene and a genome build
     gene_obj = {"hgnc_id": 257}
-    build = 38
+
     # WHEN adding the gene links
-    add_gene_links(gene_obj, build)
+    add_gene_links(gene_obj, BUILD_38)
     # THEN assert some links are added
     assert "hgnc_link" in gene_obj
 
 
-def test_ucsc_link():
+def test_ucsc_link_build37():
     """Test if ucsc link is correctly added"""
     # GIVEN a minimal gene and a genome build
     gene_obj = {"hgnc_id": 257, "ucsc_id": "uc001jwi.4"}
-    build = 37
+
     # WHEN adding the gene links
-    add_gene_links(gene_obj, build)
+    add_gene_links(gene_obj, BUILD_37)
     # THEN assert some links are added
     link = gene_obj.get("ucsc_link")
     assert link is not None
